@@ -96,7 +96,8 @@ func (s *Storage) CreateUser(userCreationRequest *model.UserCreationRequest) (*m
 			mark_read_on_view,
 			media_playback_rate,
 			block_filter_entry_rules,
-			keep_filter_entry_rules
+			keep_filter_entry_rules,
+			always_open_external_links
 	`
 
 	tx, err := s.db.Begin()
@@ -140,6 +141,7 @@ func (s *Storage) CreateUser(userCreationRequest *model.UserCreationRequest) (*m
 		&user.MediaPlaybackRate,
 		&user.BlockFilterEntryRules,
 		&user.KeepFilterEntryRules,
+		&user.AlwaysOpenExternalLinks,
 	)
 	if err != nil {
 		tx.Rollback()
@@ -204,9 +206,10 @@ func (s *Storage) UpdateUser(user *model.User) error {
 				mark_read_on_media_player_completion=$25,
 				media_playback_rate=$26,
 				block_filter_entry_rules=$27,
-				keep_filter_entry_rules=$28
+				keep_filter_entry_rules=$28,
+				always_open_external_links=$29
 			WHERE
-				id=$29
+				id=$30
 		`
 
 		_, err = s.db.Exec(
@@ -239,6 +242,7 @@ func (s *Storage) UpdateUser(user *model.User) error {
 			user.MediaPlaybackRate,
 			user.BlockFilterEntryRules,
 			user.KeepFilterEntryRules,
+			user.AlwaysOpenExternalLinks,
 			user.ID,
 		)
 		if err != nil {
@@ -273,9 +277,10 @@ func (s *Storage) UpdateUser(user *model.User) error {
 				mark_read_on_media_player_completion=$24,
 				media_playback_rate=$25,
 				block_filter_entry_rules=$26,
-				keep_filter_entry_rules=$27
+				keep_filter_entry_rules=$27,
+				always_open_external_links=$28
 			WHERE
-				id=$28
+				id=$29
 		`
 
 		_, err := s.db.Exec(
@@ -307,6 +312,7 @@ func (s *Storage) UpdateUser(user *model.User) error {
 			user.MediaPlaybackRate,
 			user.BlockFilterEntryRules,
 			user.KeepFilterEntryRules,
+			user.AlwaysOpenExternalLinks,
 			user.ID,
 		)
 
@@ -360,7 +366,8 @@ func (s *Storage) UserByID(userID int64) (*model.User, error) {
 			mark_read_on_media_player_completion,
 			media_playback_rate,
 			block_filter_entry_rules,
-			keep_filter_entry_rules
+			keep_filter_entry_rules,
+			always_open_external_links
 		FROM
 			users
 		WHERE
@@ -401,7 +408,8 @@ func (s *Storage) UserByUsername(username string) (*model.User, error) {
 			mark_read_on_media_player_completion,
 			media_playback_rate,
 			block_filter_entry_rules,
-			keep_filter_entry_rules
+			keep_filter_entry_rules,
+			always_open_external_links
 		FROM
 			users
 		WHERE
@@ -442,7 +450,8 @@ func (s *Storage) UserByField(field, value string) (*model.User, error) {
 			mark_read_on_media_player_completion,
 			media_playback_rate,
 			block_filter_entry_rules,
-			keep_filter_entry_rules
+			keep_filter_entry_rules,
+			always_open_external_links
 		FROM
 			users
 		WHERE
@@ -490,7 +499,8 @@ func (s *Storage) UserByAPIKey(token string) (*model.User, error) {
 			u.mark_read_on_media_player_completion,
 			media_playback_rate,
 			u.block_filter_entry_rules,
-			u.keep_filter_entry_rules
+			u.keep_filter_entry_rules,
+			u.always_open_external_links
 		FROM
 			users u
 		LEFT JOIN
@@ -533,6 +543,7 @@ func (s *Storage) fetchUser(query string, args ...interface{}) (*model.User, err
 		&user.MediaPlaybackRate,
 		&user.BlockFilterEntryRules,
 		&user.KeepFilterEntryRules,
+		&user.AlwaysOpenExternalLinks,
 	)
 
 	if err == sql.ErrNoRows {
@@ -646,7 +657,8 @@ func (s *Storage) Users() (model.Users, error) {
 			mark_read_on_media_player_completion,
 			media_playback_rate,
 			block_filter_entry_rules,
-			keep_filter_entry_rules
+			keep_filter_entry_rules,
+			always_open_external_links
 		FROM
 			users
 		ORDER BY username ASC
@@ -690,6 +702,7 @@ func (s *Storage) Users() (model.Users, error) {
 			&user.MediaPlaybackRate,
 			&user.BlockFilterEntryRules,
 			&user.KeepFilterEntryRules,
+			&user.AlwaysOpenExternalLinks,
 		)
 
 		if err != nil {
