@@ -93,6 +93,7 @@ type IntegrationForm struct {
 	WebhookSecret                    string
 	RSSBridgeEnabled                 bool
 	RSSBridgeURL                     string
+	RSSBridgeToken                   string
 	OmnivoreEnabled                  bool
 	OmnivoreAPIKey                   string
 	OmnivoreURL                      string
@@ -115,6 +116,13 @@ type IntegrationForm struct {
 	CuboxAPILink                     string
 	DiscordEnabled                   bool
 	DiscordWebhookLink               string
+	SlackEnabled                     bool
+	SlackWebhookLink                 string
+	PushoverEnabled                  bool
+	PushoverUser                     string
+	PushoverToken                    string
+	PushoverDevice                   string
+	PushoverPrefix                   string
 }
 
 // Merge copy form values to the model.
@@ -197,6 +205,7 @@ func (i IntegrationForm) Merge(integration *model.Integration) {
 	integration.WebhookURL = i.WebhookURL
 	integration.RSSBridgeEnabled = i.RSSBridgeEnabled
 	integration.RSSBridgeURL = i.RSSBridgeURL
+	integration.RSSBridgeToken = i.RSSBridgeToken
 	integration.OmnivoreEnabled = i.OmnivoreEnabled
 	integration.OmnivoreAPIKey = i.OmnivoreAPIKey
 	integration.OmnivoreURL = i.OmnivoreURL
@@ -219,6 +228,13 @@ func (i IntegrationForm) Merge(integration *model.Integration) {
 	integration.CuboxAPILink = i.CuboxAPILink
 	integration.DiscordEnabled = i.DiscordEnabled
 	integration.DiscordWebhookLink = i.DiscordWebhookLink
+	integration.SlackEnabled = i.SlackEnabled
+	integration.SlackWebhookLink = i.SlackWebhookLink
+	integration.PushoverEnabled = i.PushoverEnabled
+	integration.PushoverUser = i.PushoverUser
+	integration.PushoverToken = i.PushoverToken
+	integration.PushoverDevice = i.PushoverDevice
+	integration.PushoverPrefix = i.PushoverPrefix
 }
 
 // NewIntegrationForm returns a new IntegrationForm.
@@ -304,6 +320,7 @@ func NewIntegrationForm(r *http.Request) *IntegrationForm {
 		WebhookURL:                       r.FormValue("webhook_url"),
 		RSSBridgeEnabled:                 r.FormValue("rssbridge_enabled") == "1",
 		RSSBridgeURL:                     r.FormValue("rssbridge_url"),
+		RSSBridgeToken:                   r.FormValue("rssbridge_token"),
 		OmnivoreEnabled:                  r.FormValue("omnivore_enabled") == "1",
 		OmnivoreAPIKey:                   r.FormValue("omnivore_api_key"),
 		OmnivoreURL:                      r.FormValue("omnivore_url"),
@@ -326,6 +343,13 @@ func NewIntegrationForm(r *http.Request) *IntegrationForm {
 		CuboxAPILink:                     r.FormValue("cubox_api_link"),
 		DiscordEnabled:                   r.FormValue("discord_enabled") == "1",
 		DiscordWebhookLink:               r.FormValue("discord_webhook_link"),
+		SlackEnabled:                     r.FormValue("slack_enabled") == "1",
+		SlackWebhookLink:                 r.FormValue("slack_webhook_link"),
+		PushoverEnabled:                  r.FormValue("pushover_enabled") == "1",
+		PushoverUser:                     r.FormValue("pushover_user"),
+		PushoverToken:                    r.FormValue("pushover_token"),
+		PushoverDevice:                   r.FormValue("pushover_device"),
+		PushoverPrefix:                   r.FormValue("pushover_prefix"),
 	}
 }
 
