@@ -76,22 +76,24 @@ func (h *handler) updateSettings(w http.ResponseWriter, r *http.Request) {
 	}
 
 	userModificationRequest := &model.UserModificationRequest{
-		Username:              model.OptionalString(settingsForm.Username),
-		Password:              model.OptionalString(settingsForm.Password),
-		Theme:                 model.OptionalString(settingsForm.Theme),
-		Language:              model.OptionalString(settingsForm.Language),
-		Timezone:              model.OptionalString(settingsForm.Timezone),
-		EntryDirection:        model.OptionalString(settingsForm.EntryDirection),
-		EntriesPerPage:        model.OptionalNumber(settingsForm.EntriesPerPage),
-		DisplayMode:           model.OptionalString(settingsForm.DisplayMode),
-		GestureNav:            model.OptionalString(settingsForm.GestureNav),
-		DefaultReadingSpeed:   model.OptionalNumber(settingsForm.DefaultReadingSpeed),
-		CJKReadingSpeed:       model.OptionalNumber(settingsForm.CJKReadingSpeed),
-		DefaultHomePage:       model.OptionalString(settingsForm.DefaultHomePage),
-		MediaPlaybackRate:     model.OptionalNumber(settingsForm.MediaPlaybackRate),
-		BlockFilterEntryRules: model.OptionalString(settingsForm.BlockFilterEntryRules),
-		KeepFilterEntryRules:  model.OptionalString(settingsForm.KeepFilterEntryRules),
-		ExternalFontHosts:     model.OptionalString(settingsForm.ExternalFontHosts),
+		Username:               model.OptionalString(settingsForm.Username),
+		Password:               model.OptionalString(settingsForm.Password),
+		Theme:                  model.OptionalString(settingsForm.Theme),
+		Language:               model.OptionalString(settingsForm.Language),
+		Timezone:               model.OptionalString(settingsForm.Timezone),
+		EntryDirection:         model.OptionalString(settingsForm.EntryDirection),
+		EntryOrder:             model.OptionalString(settingsForm.EntryOrder),
+		EntriesPerPage:         model.OptionalNumber(settingsForm.EntriesPerPage),
+		CategoriesSortingOrder: model.OptionalString(settingsForm.CategoriesSortingOrder),
+		DisplayMode:            model.OptionalString(settingsForm.DisplayMode),
+		GestureNav:             model.OptionalString(settingsForm.GestureNav),
+		DefaultReadingSpeed:    model.OptionalNumber(settingsForm.DefaultReadingSpeed),
+		CJKReadingSpeed:        model.OptionalNumber(settingsForm.CJKReadingSpeed),
+		DefaultHomePage:        model.OptionalString(settingsForm.DefaultHomePage),
+		MediaPlaybackRate:      model.OptionalNumber(settingsForm.MediaPlaybackRate),
+		BlockFilterEntryRules:  model.OptionalString(settingsForm.BlockFilterEntryRules),
+		KeepFilterEntryRules:   model.OptionalString(settingsForm.KeepFilterEntryRules),
+		ExternalFontHosts:      model.OptionalString(settingsForm.ExternalFontHosts),
 	}
 
 	if validationErr := validator.ValidateUserModification(h.store, loggedUser.ID, userModificationRequest); validationErr != nil {
